@@ -30,10 +30,11 @@ class AbstractAppearance
 {
     public:
         virtual ~AbstractAppearance() {}
-        virtual QString defaultConfigFile() const = 0;
+        virtual bool loadSettings() = 0;
+        virtual bool saveSettings() const = 0;
         virtual bool loadSettings(const QString& path) = 0;
         virtual bool saveSettings(const QString& path) const = 0;
-        
+
         /** @returns the installed themes' paths*/
         virtual QStringList installedThemes() const = 0;
         
@@ -44,6 +45,7 @@ class AbstractAppearance
         void setFont(const QString& font);
         void setShowIconsInMenus(bool show);
         void setShowIconsInButtons(bool show);
+        void setPrimaryButtonWarpsSlider(bool enabled);
         void setToolbarStyle(const QString& style);
         
         QString getTheme() const;
@@ -55,6 +57,7 @@ class AbstractAppearance
         QString getToolbarStyle() const;
         bool getShowIconsInButtons() const;
         bool getShowIconsInMenus() const;
+        bool getPrimaryButtonWarpsSlider() const;
         
         QStringList installedThemesNames() const;
         bool hasProperty(const QString& key) const;
